/***************************************************************************
  This is the .do file to run the analysis in Huangfu and Nobles 
 ****************************************************************************/

global working ""
   // this is where the analytic data file is stored 

 
  use "$working/finalsample",clear
  
global fam i.edu age  i.marst i.cores_bk i.far i.pcepc_q  i.nrchedu_h  nrch_youngest 
global comm   comm_trans comm_schl  i.garbage i.piped healthpost  i.comm_ind i.comm_farm i.comm_service 


  /**************************************************************************
  using signal coverage to predict telecom consumption and cellphone ownership * (Table 1) */ 
******************************************************************************/
  reg telcons_d  i.sig_q i.year $fam $comm i.prov if sample==1 
  reg cell  i.sig_q $fam $comm i.prov if sample ==1


 /*******************************************************************************
  Twoway fixed effect model , (Table 3A) 
*******************************************************************************/

// weekly phone contact
xtreg contact2  i.sig_q   i.year  $fam $comm  if sample==1 , fe  vce(cluster provkabkec)
	   // randomization inference for contact frequency (Appendix table 7)
        ritest sig_q _b[1.sig_q], reps(100) seed(125) : xtreg contact2 i.sig_q i.year $fam $comm if sample==1,fe  vce(cluster provkabkec)
  
	 
 // amount of transfer giving 
xtreg lntr_down2 i.sig_q  i.year   $fam $comm  if  sample==1 & amt_d  < amt_dp99  ,fe vce(cluster provkabkec)
	// randominzation inference (Appendix table 7)
	ritest sig_q _b[1.sig_q], reps(1000) seed(125) : xtreg lntr_down2 i.sig_q i.year $fam $comm if sample==1,fe  vce(cluster provkabkec)
 
 // amount of transfer receiving    
xtreg lntr_up2 i.sig_q  i.year    $fam $comm  if  sample==1 & amt_u < amt_up99 ,fe vce(cluster provkabkec)
      // randomization inference (Appendix table 7)
  ritest sig_q _b[1.sig_q], reps(1000) seed(125) : xtreg lntr_up i.sig_q i.year $fam $comm if sample==1,fe  vce(cluster provkabkec)
  
/*******************************************************************************
  run the model on stratified sample  ,twoway fixed effect, (Table 4A) 
*******************************************************************************/

/* contact */ 
// by cores_bk marst agegp far 
g older= 0 if age>=60 & age<70
 replace older = 1 if age>=70 & age<85

 foreach var in cores_bk marst older far { 
    xtreg contact2 i.sig_q  i.year    $fam $comm  if  `var' ==0  ,fe vce(cluster provkabkec)
    xtreg contact2 i.sig_q  i.year    $fam $comm  if   `var' ==1  ,fe vce(cluster provkabkec)
 }

// by consumption tertile 
  xtreg contact2 i.sig_q  i.year   $fam $comm   if     pcepc_q ==1 ,fe vce(cluster provkabkec)
  xtreg contact2  i.sig_q  i.year   $fam $comm   if    pcepc_q ==2 ,fe vce(cluster provkabkec)
  xtreg contact  i.sig_q  i.year   $fam $comm   if    pcepc_q ==3 ,fe vce(cluster provkabkec)

/* amount giving */ 
		 
 foreach var in cores_bk marst older far { 
    xtreg lntr_down2 i.sig_q  i.year    $fam $comm  if   `var' ==0 ,fe vce(cluster provkabkec)
    xtreg lntr_down2 i.sig_q  i.year    $fam $comm  if   `var' ==1 ,fe vce(cluster provkabkec)
 
 }

// by consumption tertile 
 xtreg lntr_down2 i.sig_q  i.year   $fam $comm   if     pcepc_q ==1 ,fe vce(cluster provkabkec)
  xtreg lntr_down2  i.sig_q  i.year   $fam $comm   if    pcepc_q ==2 ,fe vce(cluster provkabkec)
  xtreg lntr_down2  i.sig_q  i.year   $fam $comm   if    pcepc_q ==3 ,fe vce(cluster provkabkec)
      

/* amount receiving  */ 
foreach var in cores_bk marst older far { 
    xtreg lntr_up2 i.sig_q  i.year    $fam $comm  if   `var' ==0 ,fe vce(cluster provkabkec)
    xtreg lntr_up2 i.sig_q  i.year    $fam $comm  if   `var' ==1 ,fe vce(cluster provkabkec)
  
		  }

// by consumption tertile 
 xtreg lntr_up2 i.sig_q  i.year   $fam $comm   if     pcepc_q ==1 ,fe vce(cluster provkabkec)
  xtreg lntr_up2  i.sig_q  i.year   $fam $comm   if    pcepc_q ==2 ,fe vce(cluster provkabkec)
  xtreg lntr_up2  i.sig_q  i.year   $fam $comm   if    pcepc_q ==3 ,fe vce(cluster provkabkec)




	
	 /*** *****************************************************
	  association between cellphone ownership in 2014 and intergenerational support (Appendix table 1)
	  *** *****************************************************/
	  
	 xtreg contact2  i.cell   i.year  $fam $comm  if sample==1 , fe  vce(cluster provkabkec)
	 xtreg lntr_down2 i.cell  i.year   $fam $comm  if  sample==1 & amt_d  < amt_dp99  ,fe vce(cluster provkabkec)
        xtreg lntr_up2 i.cell  i.year    $fam $comm  if  sample==1 & amt_u < amt_up99 ,fe vce(cluster provkabkec)
      /**************************************************************
  district level regression (appendix table  2) 
  *****************************************************************/
use "$working/finalsample",clear
 keep if sample ==1 
drop n
bys provkabkec: g n=_n 

keep if n==1

reg sig_q electricity
reg sig_q electricity $comm i.year 

reg sig_q  i.asphalt 
reg sig_q i.asphalt $comm   i.year
 
 
 
 /******** *****************************************************
     test for the parallel trend assumption (appendix table 6)  
	 ***********************************************************/
 
 // generate an indicator of whether the subdistrict will receive signal eventually 
 
 bys pidlink: egen sig2 = max(sig_q)
  label var sig2 "receive signal coverage eventually" 
  
  drop n
  bys pidlink: g n=_n
  
  tab sig2 if n==1 & sample==1
   drop n 
  sort pidlink year
  
	 
    bys pidlink : g pre2 =1 if  sig_q[_n+2] ==1 | sig_q[_n+3]==1 
	 replace pre2 = 0 if pre2==. & sig_q <.
	
	bys pidlink : g pre1 =1 if sig_q==0 &  sig_q[_n+1] ==1 & (pre2==0 ) 
	 replace pre1 = 0 if pre1==. & sig_q <.
	
	bys pidlink : g post1 =1 if sig_q ==1 & (sig_q[_n-1] ==0 | sig_q[_n-1]==. )
	 replace post1 = 0 if post1==. & sig_q <.
	
	bys pidlink : g post2 =1 if sig_q ==1 & sig_q[_n-1] ==1
	 replace post2= 0 if post2==. & sig_q <.
	 
	 
  g inter_pre2 = pre2 * sig2 
  g inter_pre1 = pre1 * sig2 
  g inter_post1 = post1 * sig2
  g inter_post2 = post2 * sig2
  
  replace inter_pre1 = 0 if year ==1997
 
	
  xtreg lntr_up2 i.year  inter_pre2 inter_pre1 inter_post1 inter_post2  ///
    $fam $comm if  amt_u2 < amt_up99 & sample ==1 ,fe vce(cluster provkabkec) 
 
	 
  xtreg lntr_down2 i.year   inter_pre2 inter_pre1 inter_post1 inter_post2  ///
   $fam  $comm  if  amt_d2 < amt_dp99 & sample ==1 , fe vce(cluster provkabkec)
 


 


  
 
